# AGPM
A round 2 of a python package manager to download eyescary development projects.

To add your package, go to EyeScary-Development/CDN on github, take a look at how to format packages, and submit a PR with your package and all the metadata and scripts
